From aee3dc325b7e0926f9097566998d0b22d9a9e51a Mon Sep 17 00:00:00 2001
From: Dimitri Papadopoulos
 <dpo@sfr.fr>
Date: Sat, 7 Aug 2021 15:22:46 +0200
Subject: [PATCH] Typos caught by codespell

---
 NEWS                        |  4 ++--
 NO-THANKS                   |  2 +-
 README.md                   |  2 +-
 TODO                        |  4 ++--
 bootstrap                   | 12 ++++++------
 bootstrap.conf              |  8 ++++----
 build-aux/edit-readme-alpha |  2 +-
 build-aux/ltmain.in         |  4 ++--
 doc/libtool.texi            |  2 +-
 libltdl/libltdl/lt_error.h  |  2 +-
 libltdl/lt__argz.c          |  2 +-
 libltdl/ltdl.c              |  4 ++--
 libtoolize.in               |  4 ++--
 m4/libtool.m4               |  8 ++++----
 mail/deplibs.html           |  2 +-
 tests/depdemo.at            |  2 +-
 tests/link-order.at         |  4 ++--
 17 files changed, 34 insertions(+), 34 deletions(-)

diff --git a/NEWS b/NEWS
index 4086a55a..53119751 100644
--- a/NEWS
+++ b/NEWS
@@ -708,7 +708,7 @@ New in 1.9b: 2004-08-29; CVS version 1.5a, Libtool team:
   libraries from dlpreopened modules.
 * libtoolize installs libtool.m4, (ltdl.m4 if used,) and various supporting
   m4 definitions to AC_CONFIG_MACRO_DIR.
-* Mode inferrence removed, shorthand for choosing modes added.
+* Mode inference removed, shorthand for choosing modes added.
 * Specifying -allow-undefined is now an error.
 * Speed up max_cmd_len check.
 * libltdl can now preopen modules from within a library, and libtool will
@@ -718,7 +718,7 @@ New in 1.9b: 2004-08-29; CVS version 1.5a, Libtool team:
   by module name.
 * New function in libltdl: lt_dlpreload_open opens all preloaded modules.
 * libltdl no longer loads shared libraries with global symbol resolution,
-  this caused problems when the symbols were intended to be overriden further
+  this caused problems when the symbols were intended to be overridden further
   up the stack; it is also not recommended practice.
 * New function in libltdl: lt_dlhandle_first, primes handle iterations (using
   lt_dlhandle_next) to filter by module interface.
diff --git a/NO-THANKS b/NO-THANKS
index 288b39eb..b06cb712 100644
--- a/NO-THANKS
+++ b/NO-THANKS
@@ -65,7 +65,7 @@ Todd Vierling			tv@netbsd.org
 Vincent Torri			vtorri@univ-evry.fr
 ##
 ## Add bug reporters, patch Authors you forgot to attribute at commit
-## time with 'git commit --author=...' and other non-patch contributers
+## time with 'git commit --author=...' and other non-patch contributors
 ## below:
 ##
 Allan McRae			allan@archlinux.org
diff --git a/README.md b/README.md
index 7dc32e42..62ed45fa 100644
--- a/README.md
+++ b/README.md
@@ -199,7 +199,7 @@ send the file `tests/testsuite.log` to the [bug mailing list][].
   - Any prerequisites of the above (such as m4, perl, tex)
 
   Note that these bootstrapping dependencies are much stricter than
-  those required to use a destributed release for your own packages.
+  those required to use a distributed release for your own packages.
   After installation, GNU Libtool is designed to work either standalone,
   or optionally with:
   - Autoconf 2.59 or later
diff --git a/TODO b/TODO
index cbec90b3..c8b1c1a7 100644
--- a/TODO
+++ b/TODO
@@ -114,7 +114,7 @@ GNU Libtool
 
 * Need to finalize the documentation, and give a specification of
   '.la' files so that people can depend on their format.  This would be
-  a good thing to put before the maintainance notes.
+  a good thing to put before the maintenance notes.
 
 * Document the installed 'libtool' and its limitations clearly (maybe implement
   --disable-script-install as well).  Or, even better, remove its limitations.
@@ -303,7 +303,7 @@ GNU Libtool
     So...I don't think it makes much difference *right now* in the amount of
     code required, or the number of functions implemented. At some point in the
     future we might want to generalize to an M+N scheme.  For the existing win32
-    $hosts, all of the funtionality would be on "one side" of the 2-step
+    $hosts, all of the functionality would be on "one side" of the 2-step
     conversion; the "other side" would be noop.  But we won't worry about the
     implicit quadratic complexity of the existing scheme for now.
 
diff --git a/bootstrap b/bootstrap
index 397a58e4..633526d0 100755
--- a/bootstrap
+++ b/bootstrap
@@ -53,7 +53,7 @@
 #
 # See gl/doc/bootstrap.texi for documentation on how to write
 # a bootstrap.conf to customize it for your project's
-# idiosyncracies.
+# idiosyncrasies.
 
 
 ## ================================================================== ##
@@ -192,7 +192,7 @@ extra_locale_categories=
 
 # Additional xgettext options to use.  Gnulib might provide you with an
 # extensive list of additional options to append to this, but gettext
-# 0.16.1 and newer appends them automaticaly, so you can safely ignore
+# 0.16.1 and newer appends them automatically, so you can safely ignore
 # the complaints from 'gnulib-tool' if your $configure_ac states:
 #
 #    AM_GNU_GETTEXT_VERSION([0.16.1])
@@ -717,7 +717,7 @@ func_require_term_colors ()
 
   # _G_HAVE_PLUSEQ_OP
   # Can be empty, in which case the shell is probed, "yes" if += is
-  # useable or anything else if it does not work.
+  # usable or anything else if it does not work.
   test -z "$_G_HAVE_PLUSEQ_OP" \
     && (eval 'x=a; x+=" b"; test "a b" = "$x"') 2>/dev/null \
     && _G_HAVE_PLUSEQ_OP=yes
@@ -867,7 +867,7 @@ eval 'func_dirname ()
 #             to NONDIR_REPLACEMENT.
 #             value returned in "$func_dirname_result"
 #   basename: Compute filename of FILE.
-#             value retuned in "$func_basename_result"
+#             value returned in "$func_basename_result"
 # For efficiency, we do not delegate to the functions above but instead
 # duplicate the functionality here.
 eval 'func_dirname_and_basename ()
@@ -1025,7 +1025,7 @@ func_mkdir_p ()
       # While some portion of DIR does not yet exist...
       while test ! -d "$_G_directory_path"; do
         # ...make a list in topmost first order.  Use a colon delimited
-	# list incase some portion of path contains whitespace.
+	# list in case some portion of path contains whitespace.
         _G_dir_list=$_G_directory_path:$_G_dir_list
 
         # If the last portion added has no slash in it, the list is done
@@ -5043,7 +5043,7 @@ func_get_version ()
     _G_app=$1
 
     # Rather than uncomment the sed script in-situ, strip the comments
-    # programatically before passing the result to $SED for evaluation.
+    # programmatically before passing the result to $SED for evaluation.
     sed_get_version=`$ECHO '# extract version within line
           s|.*[v ]\{1,\}\([0-9]\{1,\}\.[.a-z0-9-]*\).*|\1|
           t done
diff --git a/bootstrap.conf b/bootstrap.conf
index 87d4101a..173aedd1 100644
--- a/bootstrap.conf
+++ b/bootstrap.conf
@@ -23,9 +23,9 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 
-## -------------------------------- ##
-## User overrideable command paths. ##
-## -------------------------------- ##
+## ------------------------------- ##
+## User overridable command paths. ##
+## ------------------------------- ##
 
 : "${MAKE=make}"
 
@@ -268,7 +268,7 @@ func_add_hook func_fini libtool_readme_release_package_substitutions
 # not changing the timestamp of config-h.in unless the file contents
 # are updated.  Unfortunately config-h.in depends on aclocal.m4, which
 # *is* updated, so running 'libtoolize --ltdl=. && configure && make'
-# causes autoheader to be called... undesireable for users that do not
+# causes autoheader to be called... undesirable for users that do not
 # have it!  Fudge the timestamp to prevent that:
 libtool_fudge_timestamps ()
 {
diff --git a/build-aux/edit-readme-alpha b/build-aux/edit-readme-alpha
index e602c11d..3b909c4b 100755
--- a/build-aux/edit-readme-alpha
+++ b/build-aux/edit-readme-alpha
@@ -23,7 +23,7 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 ####
 
-# We used to maintain separate (but extremely similiar!) README and
+# We used to maintain separate (but extremely similar!) README and
 # README.alpha files, and had 'make dist' include the right one in a
 # distribution based on the contests of '$(VERSION)'.
 #
diff --git a/build-aux/ltmain.in b/build-aux/ltmain.in
index 96b37003..0e97c457 100644
--- a/build-aux/ltmain.in
+++ b/build-aux/ltmain.in
@@ -3876,7 +3876,7 @@ EOF
         {
           /* however, if there is an option in the LTWRAPPER_OPTION_PREFIX
              namespace, but it is not one of the ones we know about and
-             have already dealt with, above (inluding dump-script), then
+             have already dealt with, above (including dump-script), then
              report an error. Otherwise, targets might begin to believe
              they are allowed to use options in the LTWRAPPER_OPTION_PREFIX
              namespace. The first time any user complains about this, we'll
@@ -4052,7 +4052,7 @@ base_name (const char *name)
   const char *base;
 
 #if defined HAVE_DOS_BASED_FILE_SYSTEM
-  /* Skip over the disk name in MSDOS pathnames. */
+  /* Skip over the disk name in MS-DOS pathnames. */
   if (isalpha ((unsigned char) name[0]) && name[1] == ':')
     name += 2;
 #endif
diff --git a/doc/libtool.texi b/doc/libtool.texi
index 3411b377..5c45ae9a 100644
--- a/doc/libtool.texi
+++ b/doc/libtool.texi
@@ -2426,7 +2426,7 @@ system, this variable can be used to modify that path list, as follows
 (@code{LT_SYS_LIBRARY_PATH} is a colon-delimited list like @code{PATH}):
 @itemize @bullet
 @item @code{path:}
-The heuristically determined paths will be appened after the trailing
+The heuristically determined paths will be appended, after the trailing
 colon;
 @item @code{:path}
 The heuristically determined paths will be prepended before the leading
diff --git a/libltdl/libltdl/lt_error.h b/libltdl/libltdl/lt_error.h
index 75f7fab2..c30586b1 100644
--- a/libltdl/libltdl/lt_error.h
+++ b/libltdl/libltdl/lt_error.h
@@ -41,7 +41,7 @@ LT_BEGIN_C_DECLS
    this way allows us to expand the macro in different contexts with
    confidence that the enumeration of symbolic names will map correctly
    onto the table of error strings.  \0 is appended to the strings to
-   expilicitely initialize the string terminator. */
+   explicitly initialize the string terminator. */
 #define lt_dlerror_table						\
     LT_ERROR(UNKNOWN,		    "unknown error\0")			\
     LT_ERROR(DLOPEN_NOT_SUPPORTED,  "dlopen support not available\0")	\
diff --git a/libltdl/lt__argz.c b/libltdl/lt__argz.c
index 7161dfad..faaf9662 100644
--- a/libltdl/lt__argz.c
+++ b/libltdl/lt__argz.c
@@ -156,7 +156,7 @@ argz_insert (char **pargz, size_t *pargz_len, char *before, const char *entry)
       return ENOMEM;
 
     /* Make BEFORE point to the equivalent offset in ARGZ that it
-       used to have in *PARGZ incase realloc() moved the block.  */
+       used to have in *PARGZ in case realloc() moved the block.  */
     before = argz + offset;
 
     /* Move the ARGZ entries starting at BEFORE up into the new
diff --git a/libtoolize.in b/libtoolize.in
index 755b80ee..9126162c 100644
--- a/libtoolize.in
+++ b/libtoolize.in
@@ -516,7 +516,7 @@ func_serial_max ()
     my_sed_rest='s/^[0-9][1-9]*\.*//'
     my_sed_digits='s/[^0-9.]//g'
 
-    # Incase they turn out to be the same, we'll set it to empty
+    # In case they turn out to be the same, we'll set it to empty
     func_serial_max_result=
 
     test "X$1$2" = X`$ECHO "$1$2" | $SED "$my_sed_digits"` || {
@@ -682,7 +682,7 @@ func_serial_update ()
       func_notquiet_hdr "$my_msg_var" "'$my_destfile' is already up to date."
     fi
 
-    # Do this after the copy for hand maintained 'aclocal.m4', incase
+    # Do this after the copy for hand maintained 'aclocal.m4', in case
     # it has 'm4_include([DESTFILE])', so the copy effectively already
     # updated 'aclocal.m4'.
     my_included_files=`func_included_files aclocal.m4`
diff --git a/m4/libtool.m4 b/m4/libtool.m4
index f2d1f398..a9cd9ec3 100644
--- a/m4/libtool.m4
+++ b/m4/libtool.m4
@@ -614,7 +614,7 @@ m4_popdef([AS_MESSAGE_LOG_FD])])])# _LT_GENERATED_FILE_INIT
 # LT_OUTPUT
 # ---------
 # This macro allows early generation of the libtool script (before
-# AC_OUTPUT is called), incase it is used in configure for compilation
+# AC_OUTPUT is called), in case it is used in configure for compilation
 # tests.
 AC_DEFUN([LT_OUTPUT],
 [: ${CONFIG_LT=./config.lt}
@@ -651,7 +651,7 @@ configured by $[0], generated by m4_PACKAGE_STRING.
 
 Copyright (C) 2011 Free Software Foundation, Inc.
 This config.lt script is free software; the Free Software Foundation
-gives unlimited permision to copy, distribute and modify it."
+gives unlimited permission to copy, distribute and modify it."
 
 while test 0 != $[#]
 do
@@ -1497,7 +1497,7 @@ _LT_DECL([], [AR], [1], [The archiver])
 
 # Use ARFLAGS variable as AR's operation code to sync the variable naming with
 # Automake.  If both AR_FLAGS and ARFLAGS are specified, AR_FLAGS should have
-# higher priority because thats what people were doing historically (setting
+# higher priority because that's what people were doing historically (setting
 # ARFLAGS for automake and AR_FLAGS for libtool).  FIXME: Make the AR_FLAGS
 # variable obsoleted/removed.
 
@@ -2889,7 +2889,7 @@ linux* | k*bsd*-gnu | kopensolaris*-gnu | gnu*)
   # before this can be enabled.
   hardcode_into_libs=yes
 
-  # Ideally, we could use ldconfig to report *all* directores which are
+  # Ideally, we could use ldconfig to report *all* directories which are
   # searched for libraries, however this is still not possible.  Aside from not
   # being certain /sbin/ldconfig is available, command
   # 'ldconfig -N -X -v | grep ^/' on 64bit Fedora does not report /usr/lib64,
diff --git a/mail/deplibs.html b/mail/deplibs.html
index 6b4dccb0..758bcdb4 100644
--- a/mail/deplibs.html
+++ b/mail/deplibs.html
@@ -49,7 +49,7 @@ revealed these kinds of inconsistencies.
 
 <h2>The problem</h2>
 
-<p>My original inter-library dependency code received rigourous testing
+<p>My original inter-library dependency code received rigorous testing
 in beta releases of <a href="http://www.red-bean.com/guile/">GNU
 Guile</a>.  As soon as the Guile people started using my code, I
 received a flood of bug reports.  People were reporting that
diff --git a/tests/depdemo.at b/tests/depdemo.at
index 0c099506..b963b04a 100644
--- a/tests/depdemo.at
+++ b/tests/depdemo.at
@@ -131,7 +131,7 @@ int main (int argc, char **argv)
 }
 ]])
 
-# Create 4 directorys of mostly identical files.
+# Create 4 directories of mostly identical files.
 for i in 1 2 3 4; do
   mkdir l$i
 
diff --git a/tests/link-order.at b/tests/link-order.at
index d762084b..a2699d6f 100644
--- a/tests/link-order.at
+++ b/tests/link-order.at
@@ -50,7 +50,7 @@ for i in old new; do
 
   cat >src/a_$i.c <<EOF
 /* w32 fun, MSVC needs to dllimport when using a shared library, so use
- * DLL_EXPORT to discriminate as that happens to coinside in this case.
+ * DLL_EXPORT to discriminate as that happens to coincide in this case.
  * gnu has auto import.
  */
 #if defined _MSC_VER && defined DLL_EXPORT
@@ -65,7 +65,7 @@ EOF
 
   cat >src/b_$i.c <<EOF
 /* w32 fun, MSVC needs to dllimport when using a shared library, so use
- * DLL_EXPORT to discriminate as that happens to coinside in this case.
+ * DLL_EXPORT to discriminate as that happens to coincide in this case.
  * gnu has auto import.
  */
 #if defined _MSC_VER && defined DLL_EXPORT
diff --git a/libltdl/ltdl.c b/libltdl/ltdl.c
index bdb1ce64..dd8dd4d6 100644
--- a/libltdl/ltdl.c
+++ b/libltdl/ltdl.c
@@ -1666,7 +1666,7 @@ lt_dlopenadvise (const char *filename, lt_dladvise advise)
       || !advise->try_ext
       || has_library_ext (filename))
     {
       /* Just incase we missed a code path in try_dlopen() that reports
 	 an error, but forgot to reset handle... */
       if (try_dlopen (&handle, filename, NULL, advise) != 0)
 	return 0;
@@ -1970,7 +1970,7 @@ lt_dlclose (lt_dlhandle handle)
   cur->info.ref_count--;
 
   /* Note that even with resident modules, we must track the ref_count
-     correctly incase the user decides to reset the residency flag
+     correctly in case the user decides to reset the residency flag
      later (even though the API makes no provision for that at the
      moment).  */
   if (cur->info.ref_count <= 0 && !LT_DLIS_RESIDENT (cur))
@@ -1666,7 +1666,7 @@ lt_dlopenadvise (const char *filename, lt_dladvise advise)
       || has_library_ext (filename))
     {
-      /* Just incase we missed a code path in try_dlopen() that reports
+      /* Just in case we missed a code path in try_dlopen() that reports
 	 an error, but forgot to reset handle... */
       if (try_dlopen (&handle, filename, NULL, advise) != 0)
-- 
2.25.1

